"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_native_1 = require("react-native");
var Touchable_1 = require("./Touchable");
var View_1 = require("./View");
var Text_1 = require("./Text");
var Loading_1 = require("./Loading");
var Log_1 = require("../../modules/logger/Log");
var MessageItem = (function (_super) {
    __extends(MessageItem, _super);
    function MessageItem() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            top: new react_native_1.Animated.Value(-100),
            fade: new react_native_1.Animated.Value(0),
            itemHeight: 0
        };
        return _this;
    }
    MessageItem.prototype.onLayout = function (event) {
        var itemHeight = event.nativeEvent.layout.height;
        this.setState({ itemHeight: itemHeight });
        Log_1.default.info('[MessageItem]', itemHeight);
    };
    MessageItem.prototype.show = function () {
        var _this = this;
        if (this.animation) {
            this.animation.stop();
        }
        requestAnimationFrame(function () {
            _this.animation = react_native_1.Animated.parallel([
                react_native_1.Animated.timing(_this.state.fade, {
                    toValue: 1,
                    duration: 600
                }),
                react_native_1.Animated.spring(_this.state.top, {
                    toValue: 0,
                    friction: 8
                })
            ]);
            _this.animation.start();
        });
    };
    MessageItem.prototype.hide = function (cb) {
        var _this = this;
        var offset = this.state.itemHeight < 1 ? 50 : this.state.itemHeight;
        if (this.animation) {
            this.animation.stop();
        }
        requestAnimationFrame(function () {
            _this.animation = react_native_1.Animated.parallel([
                react_native_1.Animated.timing(_this.state.fade, {
                    toValue: 0,
                    duration: 200
                }),
                react_native_1.Animated.spring(_this.state.top, {
                    toValue: offset * -1,
                    friction: 8
                })
            ]);
            _this.animation.start(cb);
        });
    };
    MessageItem.prototype.componentDidMount = function () {
        this.show();
        this.autoDismissSetup();
    };
    MessageItem.prototype.componentWillUnmount = function () {
        if (this.animation) {
            this.animation.stop();
        }
    };
    MessageItem.prototype.autoDismissSetup = function () {
        var _this = this;
        var item = this.props.item || {};
        if (this.timeoutDismiss) {
            clearTimeout(this.timeoutDismiss);
        }
        if (item.autoDismiss) {
            this.timeoutDismiss = setTimeout(function () {
                _this.props.onHide();
            }, item.autoDismiss * 1000);
        }
    };
    MessageItem.prototype.componentDidUpdate = function (prevProps, prevState) {
        var autoDismissReload = false;
        var item = this.props.item || {};
        var prevItem = prevProps.item || {};
        if (prevItem.message !== item.message) {
            autoDismissReload = true;
        }
        else if (prevItem.autoDismiss !== item.autoDismiss) {
            autoDismissReload = true;
        }
        else if (prevItem.isLoading !== item.isLoading) {
            autoDismissReload = true;
        }
        autoDismissReload && this.autoDismissSetup();
    };
    MessageItem.prototype.render = function () {
        var _a = this.props, item = _a.item, onHide = _a.onHide, level = _a.level, props = __rest(_a, ["item", "onHide", "level"]);
        var _b = this.state, fade = _b.fade, top = _b.top;
        var levelMessage = level || 'default';
        return (React.createElement(react_native_1.Animated.View, { style: { opacity: fade, marginTop: top } },
            React.createElement(Touchable_1.default, { onLayout: this.onLayout.bind(this), onPress: onHide },
                React.createElement(View_1.default, { ref: 'content', style: [styles.container] },
                    item.isLoading &&
                        React.createElement(Loading_1.default, { inverted: true, style: styles.icon, size: 18 }),
                    React.createElement(View_1.default, { style: [styles.infoContainer] },
                        item.title && React.createElement(Text_1.default, { style: [styles.title] }, item.title),
                        item.message &&
                            React.createElement(Text_1.default, { style: [styles.message] }, item.message))))));
    };
    return MessageItem;
}(React.Component));
exports.default = MessageItem;
var styles = react_native_1.StyleSheet.create({
    container: {
        backgroundColor: '#8abb11',
        borderRadius: 4,
        padding: 10,
        marginBottom: 5,
        flexDirection: 'row'
    },
    icon: {
        marginRight: 5
        // color: 'red'
    },
    iconContainer: {
        justifyContent: 'center',
        marginRight: 3
    },
    infoContainer: {
        //justifyContent: 'center',
        // flexDirection: 'col',
        //alignItems: 'center',
        flex: 1
    },
    title: {
        fontSize: 11,
        color: '#fff'
    },
    message: {
        fontSize: 12,
        color: '#fff'
    }
});
