"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_native_1 = require("react-native");
var Screen_1 = require("../../modules/listener/Screen");
var View_1 = require("./View");
var Text_1 = require("./Text");
var Emitter_1 = require("../../modules/listener/Emitter");
var Button_1 = require("./Button");
var Translator_1 = require("../../modules/i18n/Translator");
var ScrollView_1 = require("./ScrollView");
var OptionItem_1 = require("./OptionItem");
var ModalActionItem = (function (_super) {
    __extends(ModalActionItem, _super);
    function ModalActionItem() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            fade: new react_native_1.Animated.Value(0),
            bottom: new react_native_1.Animated.Value(0),
            width: Screen_1.default.getDimensions().width,
            height: Screen_1.default.getDimensions().height,
            isVisible: true
        };
        return _this;
    }
    ModalActionItem.prototype.componentDidMount = function () {
        this.show();
    };
    ModalActionItem.prototype.onLayout = function (event) {
        var _a = event.nativeEvent.layout, width = _a.width, height = _a.height;
        var item = this.props.item;
        var itemWidth = item.maxWidth || 400;
        //Log.info('[ModalActionItem]', 'onLayout', width, height, itemWidth, item);
        if (width < itemWidth) {
            itemWidth = width;
        }
        this.setState({ width: itemWidth, height: height });
    };
    ModalActionItem.prototype.show = function () {
        var _this = this;
        var height = this.state.height;
        var bottom = new react_native_1.Animated.Value(height * -1);
        this.setState({ bottom: bottom }, function () {
            requestAnimationFrame(function () {
                _this.animation = react_native_1.Animated.parallel([
                    react_native_1.Animated.timing(_this.state.fade, {
                        toValue: 1,
                        delay: 200
                    }),
                    react_native_1.Animated.timing(_this.state.bottom, {
                        toValue: 0
                    })
                ]);
                _this.animation.start();
            });
        });
    };
    ModalActionItem.prototype.componentWillUnmount = function () {
        Emitter_1.default.off(this.onDimensionsChangeListener);
        if (this.animation) {
            this.animation.stop();
        }
    };
    ModalActionItem.prototype.hide = function (cb) {
        if (this.animation) {
            this.animation.stop();
        }
        var height = this.state.height;
        this.animation = react_native_1.Animated.parallel([
            react_native_1.Animated.timing(this.state.fade, {
                toValue: 0,
                duration: 300
            }),
            react_native_1.Animated.timing(this.state.bottom, {
                toValue: height * -1,
                duration: 200
            })
        ]);
        this.animation.start(cb);
    };
    ModalActionItem.prototype.onReturn = function () {
        if (this.props.item.onReturn) {
            this.props.item.onReturn();
        }
        this.props.onHide();
    };
    ModalActionItem.prototype.render = function () {
        var _a = this.state, fade = _a.fade, bottom = _a.bottom, width = _a.width, height = _a.height;
        var _b = this.props, item = _b.item, onHide = _b.onHide;
        // let maxHeight = height - 50;
        return (React.createElement(View_1.default, { style: [styles.container, item.containerStyle] },
            React.createElement(react_native_1.Animated.View, { style: { zIndex: 10, bottom: bottom, flex: 1 } },
                React.createElement(react_native_1.TouchableWithoutFeedback, { onPress: onHide },
                    React.createElement(View_1.default, { style: [styles.container] },
                        React.createElement(View_1.default, { onLayout: this.onLayout.bind(this), ref: 'content', style: [styles.content, { width: width }] },
                            item.title &&
                                React.createElement(View_1.default, { style: [styles.header] },
                                    typeof item.title === 'object' && item.title,
                                    typeof item.title !== 'object' &&
                                        React.createElement(Text_1.default, { style: styles.title }, item.title.toUpperCase())),
                            item.body &&
                                React.createElement(View_1.default, { style: [styles.body] },
                                    typeof item.body === 'object' && item.body,
                                    typeof item.body !== 'object' &&
                                        React.createElement(Text_1.default, { style: styles.bodyText }, item.body)),
                            item.actions &&
                                React.createElement(ScrollView_1.default, { horizontal: false, style: styles.actionsContainer }, item.actions.map(function (option, index) {
                                    return React.createElement(OptionItem_1.default, __assign({}, option, { key: index }));
                                })),
                            React.createElement(View_1.default, { style: [styles.footer] }, item.onReturn &&
                                React.createElement(Button_1.default, { title: item.actionReturn || Translator_1._('Return'), style: styles.returnButton, onPress: this.onReturn.bind(this) })))))),
            React.createElement(react_native_1.Animated.View, { style: [styles.backdrop, { opacity: fade }] })));
    };
    return ModalActionItem;
}(React.Component));
exports.default = ModalActionItem;
var styles = react_native_1.StyleSheet.create({
    returnButton: {
        flex: 1
    },
    actionsContainer: {
        marginBottom: 10
    },
    container: {
        zIndex: 10,
        position: 'absolute',
        justifyContent: 'flex-end',
        alignItems: 'center',
        right: 0,
        left: 0,
        top: 0,
        bottom: 0
    },
    backdrop: {
        backgroundColor: 'rgba(0,0,0,0.25)',
        zIndex: 9,
        //flex: 1,
        //position: Platform.OS === 'web' ? 'fixed' : 'absolute',
        position: 'absolute',
        right: 0,
        left: 0,
        top: 0,
        bottom: 0
    },
    footer: {
        flexDirection: 'row',
        padding: 10,
        borderTopWidth: 1,
        borderTopColor: '#f4f4f4'
    },
    background: {
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        backgroundColor: '#000'
    },
    title: {
        fontSize: 12,
        textAlign: 'center',
        color: '#444',
        margin: 10,
        fontWeight: '500'
    },
    header: {},
    body: {
        padding: 5,
        paddingTop: 0,
        flexShrink: 1
        //flex:1,
    },
    bodyText: {
        padding: 5
    },
    content: {
        backgroundColor: '#F9F9F9',
        borderTopLeftRadius: 4,
        borderTopRightRadius: 4
    }
});
